package org.josht.utils
{
   public class ColorUtil
   {
      public function ColorUtil()
      {
         super();
      }
      
      public static function brightness(param1:uint) : Number
      {
         var _loc2_:Number = red(param1) / 255;
         var _loc3_:Number = green(param1) / 255;
         var _loc4_:Number = blue(param1) / 255;
         return Math.max(_loc2_,_loc3_,_loc4_);
      }
      
      public static function red(param1:uint) : uint
      {
         return param1 >> 16 & 0xFF;
      }
      
      public static function green(param1:uint) : uint
      {
         return param1 >> 8 & 0xFF;
      }
      
      public static function fromARGB(param1:uint, param2:uint, param3:uint, param4:uint) : uint
      {
         return (param1 << 24) + fromRGB(param2,param3,param4);
      }
      
      public static function blendColors(param1:Number, param2:Number, param3:Number = 0.5) : Number
      {
         var _loc4_:Number = 1 - param3;
         var _loc5_:uint = ColorUtil.red(param1);
         var _loc6_:uint = ColorUtil.green(param1);
         var _loc7_:uint = ColorUtil.blue(param1);
         param1 = ColorUtil.fromRGB(_loc5_ * param3,_loc6_ * param3,_loc7_ * param3);
         _loc5_ = ColorUtil.red(param2);
         _loc6_ = ColorUtil.green(param2);
         _loc7_ = ColorUtil.blue(param2);
         param2 = ColorUtil.fromRGB(_loc5_ * _loc4_,_loc6_ * _loc4_,_loc7_ * _loc4_);
         return param1 + param2;
      }
      
      public static function saturation(param1:uint) : Number
      {
         var _loc2_:Number = red(param1) / 255;
         var _loc3_:Number = green(param1) / 255;
         var _loc4_:Number = blue(param1) / 255;
         var _loc5_:Number = Math.max(_loc2_,_loc3_,_loc4_);
         var _loc6_:Number = Math.min(_loc2_,_loc3_,_loc4_);
         var _loc7_:Number = _loc5_ - _loc6_;
         var _loc8_:Number = 0;
         var _loc9_:Number = _loc5_;
         if(_loc7_ != 0 && _loc9_ != 0)
         {
            _loc8_ = _loc7_ / _loc5_;
         }
         return _loc8_;
      }
      
      public static function blue(param1:uint) : uint
      {
         return param1 & 0xFF;
      }
      
      public static function fromRGB(param1:uint, param2:uint, param3:uint) : uint
      {
         return (param1 << 16) + (param2 << 8) + param3;
      }
      
      public static function fromHSB(param1:Number, param2:Number, param3:Number) : uint
      {
         if(param2 == 0)
         {
            return fromRGB(param3 * 255,param3 * 255,param3 * 255);
         }
         var _loc4_:Number = 0;
         var _loc5_:Number = 0;
         var _loc6_:Number = 0;
         var _loc7_:Number = param1 * 6;
         var _loc8_:Number = Math.floor(_loc7_);
         var _loc9_:Number = _loc7_ - _loc8_;
         var _loc10_:Number = param3 * (1 - param2);
         var _loc11_:Number = param3 * (1 - _loc9_ * param2);
         var _loc12_:Number = param3 * (1 - (1 - _loc9_) * param2);
         switch(_loc8_)
         {
            case 0:
               _loc4_ = param3;
               _loc5_ = _loc12_;
               _loc6_ = _loc10_;
               break;
            case 1:
               _loc4_ = _loc11_;
               _loc5_ = param3;
               _loc6_ = _loc10_;
               break;
            case 2:
               _loc4_ = _loc10_;
               _loc5_ = param3;
               _loc6_ = _loc12_;
               break;
            case 3:
               _loc4_ = _loc10_;
               _loc5_ = _loc11_;
               _loc6_ = param3;
               break;
            case 4:
               _loc4_ = _loc12_;
               _loc5_ = _loc10_;
               _loc6_ = param3;
               break;
            case 5:
               _loc4_ = param3;
               _loc5_ = _loc10_;
               _loc6_ = _loc11_;
         }
         _loc4_ = Math.round(_loc4_ * 255);
         _loc5_ = Math.round(_loc5_ * 255);
         _loc6_ = Math.round(_loc6_ * 255);
         return fromRGB(_loc4_,_loc5_,_loc6_);
      }
      
      public static function alpha(param1:uint) : uint
      {
         return param1 >> 24 & 0xFF;
      }
      
      public static function hue(param1:uint) : Number
      {
         var _loc9_:Number = NaN;
         var _loc10_:Number = NaN;
         var _loc11_:Number = NaN;
         var _loc2_:Number = red(param1) / 255;
         var _loc3_:Number = green(param1) / 255;
         var _loc4_:Number = blue(param1) / 255;
         var _loc5_:Number = Math.max(_loc2_,_loc3_,_loc4_);
         var _loc6_:Number = Math.min(_loc2_,_loc3_,_loc4_);
         var _loc7_:Number = _loc5_ - _loc6_;
         var _loc8_:Number = 0;
         if(_loc7_ != 0)
         {
            _loc9_ = (_loc5_ - _loc2_) / _loc7_;
            _loc10_ = (_loc5_ - _loc3_) / _loc7_;
            _loc11_ = (_loc5_ - _loc4_) / _loc7_;
            switch(_loc5_)
            {
               case _loc2_:
                  _loc8_ = _loc11_ - _loc10_;
                  break;
               case _loc3_:
                  _loc8_ = 2 + _loc9_ - _loc11_;
                  break;
               case _loc4_:
                  _loc8_ = 4 + _loc10_ - _loc9_;
            }
            _loc8_ /= 6;
         }
         if(_loc8_ < 0)
         {
            _loc8_++;
         }
         if(_loc8_ > 1)
         {
            _loc8_--;
         }
         return _loc8_;
      }
   }
}

